Crate xfce4_ui

Crate xfce4_ui 

xfce4-ui

This crate is a safe API wrapper around libxfce4ui, Xfce’s UI utility library.

How to use

Add to your project’s Cargo.toml:

[dependencies]
xfce4-ui = "0.1"

The crate currently contains no useful functionality, and is only present to support other crates that depend on its FFI types.

In the future, it will be augmented to wrap libxfce4ui functions and widgets.